@@ -2,8 +2,8 @@
 
 Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
     1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Massachusetts
-    Institute of Technology
+    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
+    2017, 2018 Massachusetts Institute of Technology
 
 This file is part of MIT/GNU Scheme.
 
@@ -223,16 +223,7 @@ finite_flonum_p (SCHEME_OBJECT x)
 bool
 flonum_is_finite_p (SCHEME_OBJECT x)
 {
-  return double_is_finite_p (FLONUM_TO_DOUBLE (x));
-}
-
-bool
-double_is_finite_p (double x)
-{
-  return
-    (((x > 1.0) || (x < -1.0))
-     ? (x != (x / 2.0))
-     : ((x <= 1.0) && (x >= -1.0)));
+  return (isfinite (FLONUM_TO_DOUBLE (x)));
 }
 
 bool
